@@ -18,7 +18,9 @@ get_results = function(
   }
 
   cr = httr::content(res)
-  return(list(response = res, content = cr))
+  L = list(response = res, content = cr)
+  class(L) = "lp_results"
+  return(L)
 }
 
 
@@ -29,10 +31,14 @@ post_type = function(
   nonstop = FALSE, ...) {
 
   res = httr::POST(url,
-                   content_type(type), ...)
+                   ..., httr::content_type(type))
   if (verbose) {
     message("POST command is:")
-    print(res)
+    r = res
+    parsed_url = httr::parse_url(r$url)
+    parsed_url$query$api_key = NULL
+    r$url = httr::build_url(parsed_url)
+    print(r)
   }
   if (!nonstop) {
     httr::stop_for_status(res)
@@ -41,5 +47,7 @@ post_type = function(
   }
 
   cr = httr::content(res)
-  return(list(response = res, content = cr))
+  L = list(response = res, content = cr)
+  class(L) = "lp_results"
+  return(L)
 }
