@@ -5,7 +5,7 @@
 #'
 #' @note See \url{https://leanpub.com/help/api}
 #'
-#' @return List of the result of the \code{\link{GET}} call and
+#' @return List of the result of the \code{\link[httr]{GET}} call and
 #' the content
 #' @importFrom httr progress warn_for_status write_disk
 #' @export
@@ -13,12 +13,12 @@
 #' if (lp_have_api_key()) {
 #' slug = "biostatmethods"
 #' res = lp_download(slug, verbose = FALSE, nonstop = TRUE, error = FALSE,
-#' format = "mobi")
+#' format = "epub")
 #' file.exists(res)
 #' }
 lp_download = function(
   slug,
-  format = c("pdf", "mobi", "epub"),
+  format = c("pdf", "epub"),
   api_key = NULL,
   secure = TRUE,
   verbose = TRUE,
