@@ -4,7 +4,7 @@
 #'
 #' @note See \url{https://leanpub.com/help/api}
 #'
-#' @return List of the result of the \code{\link{GET}} call and
+#' @return List of the result of the \code{\link[httr]{GET}} call and
 #' the content
 #' @export
 #' @examples
@@ -20,10 +20,9 @@ lp_publish = function(
   secure = TRUE,
   verbose = TRUE,
   ...) {
-  L = lp_get_wrapper(
+  L = lp_post_wrapper(
     slug = slug,
     endpoint = "/publish",
-    verb = "POST",
     api_key = api_key,
     secure = secure,
     verbose = verbose,
